# coding: utf-8

"""
    ORCID Member

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: Latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from orcid_api_v3.models.source_client_id_v30 import SourceClientIdV30  # noqa: F401,E501
from orcid_api_v3.models.source_name_v30 import SourceNameV30  # noqa: F401,E501
from orcid_api_v3.models.source_orcid_v30 import SourceOrcidV30  # noqa: F401,E501


class SourceV30(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'source_orcid': 'SourceOrcidV30',
        'source_client_id': 'SourceClientIdV30',
        'source_name': 'SourceNameV30',
        'assertion_origin_orcid': 'SourceOrcidV30',
        'assertion_origin_client_id': 'SourceClientIdV30',
        'assertion_origin_name': 'SourceNameV30'
    }

    attribute_map = {
        'source_orcid': 'source-orcid',
        'source_client_id': 'source-client-id',
        'source_name': 'source-name',
        'assertion_origin_orcid': 'assertion-origin-orcid',
        'assertion_origin_client_id': 'assertion-origin-client-id',
        'assertion_origin_name': 'assertion-origin-name'
    }

    def __init__(self, source_orcid=None, source_client_id=None, source_name=None, assertion_origin_orcid=None, assertion_origin_client_id=None, assertion_origin_name=None):  # noqa: E501
        """SourceV30 - a model defined in Swagger"""  # noqa: E501
        self._source_orcid = None
        self._source_client_id = None
        self._source_name = None
        self._assertion_origin_orcid = None
        self._assertion_origin_client_id = None
        self._assertion_origin_name = None
        self.discriminator = None
        if source_orcid is not None:
            self.source_orcid = source_orcid
        if source_client_id is not None:
            self.source_client_id = source_client_id
        if source_name is not None:
            self.source_name = source_name
        if assertion_origin_orcid is not None:
            self.assertion_origin_orcid = assertion_origin_orcid
        if assertion_origin_client_id is not None:
            self.assertion_origin_client_id = assertion_origin_client_id
        if assertion_origin_name is not None:
            self.assertion_origin_name = assertion_origin_name

    @property
    def source_orcid(self):
        """Gets the source_orcid of this SourceV30.  # noqa: E501


        :return: The source_orcid of this SourceV30.  # noqa: E501
        :rtype: SourceOrcidV30
        """
        return self._source_orcid

    @source_orcid.setter
    def source_orcid(self, source_orcid):
        """Sets the source_orcid of this SourceV30.


        :param source_orcid: The source_orcid of this SourceV30.  # noqa: E501
        :type: SourceOrcidV30
        """

        self._source_orcid = source_orcid

    @property
    def source_client_id(self):
        """Gets the source_client_id of this SourceV30.  # noqa: E501


        :return: The source_client_id of this SourceV30.  # noqa: E501
        :rtype: SourceClientIdV30
        """
        return self._source_client_id

    @source_client_id.setter
    def source_client_id(self, source_client_id):
        """Sets the source_client_id of this SourceV30.


        :param source_client_id: The source_client_id of this SourceV30.  # noqa: E501
        :type: SourceClientIdV30
        """

        self._source_client_id = source_client_id

    @property
    def source_name(self):
        """Gets the source_name of this SourceV30.  # noqa: E501


        :return: The source_name of this SourceV30.  # noqa: E501
        :rtype: SourceNameV30
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """Sets the source_name of this SourceV30.


        :param source_name: The source_name of this SourceV30.  # noqa: E501
        :type: SourceNameV30
        """

        self._source_name = source_name

    @property
    def assertion_origin_orcid(self):
        """Gets the assertion_origin_orcid of this SourceV30.  # noqa: E501


        :return: The assertion_origin_orcid of this SourceV30.  # noqa: E501
        :rtype: SourceOrcidV30
        """
        return self._assertion_origin_orcid

    @assertion_origin_orcid.setter
    def assertion_origin_orcid(self, assertion_origin_orcid):
        """Sets the assertion_origin_orcid of this SourceV30.


        :param assertion_origin_orcid: The assertion_origin_orcid of this SourceV30.  # noqa: E501
        :type: SourceOrcidV30
        """

        self._assertion_origin_orcid = assertion_origin_orcid

    @property
    def assertion_origin_client_id(self):
        """Gets the assertion_origin_client_id of this SourceV30.  # noqa: E501


        :return: The assertion_origin_client_id of this SourceV30.  # noqa: E501
        :rtype: SourceClientIdV30
        """
        return self._assertion_origin_client_id

    @assertion_origin_client_id.setter
    def assertion_origin_client_id(self, assertion_origin_client_id):
        """Sets the assertion_origin_client_id of this SourceV30.


        :param assertion_origin_client_id: The assertion_origin_client_id of this SourceV30.  # noqa: E501
        :type: SourceClientIdV30
        """

        self._assertion_origin_client_id = assertion_origin_client_id

    @property
    def assertion_origin_name(self):
        """Gets the assertion_origin_name of this SourceV30.  # noqa: E501


        :return: The assertion_origin_name of this SourceV30.  # noqa: E501
        :rtype: SourceNameV30
        """
        return self._assertion_origin_name

    @assertion_origin_name.setter
    def assertion_origin_name(self, assertion_origin_name):
        """Sets the assertion_origin_name of this SourceV30.


        :param assertion_origin_name: The assertion_origin_name of this SourceV30.  # noqa: E501
        :type: SourceNameV30
        """

        self._assertion_origin_name = assertion_origin_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SourceV30, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SourceV30):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ORCID Member

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: Latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class DisambiguatedOrganizationV30(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'disambiguated_organization_identifier': 'str',
        'disambiguation_source': 'str'
    }

    attribute_map = {
        'disambiguated_organization_identifier': 'disambiguated-organization-identifier',
        'disambiguation_source': 'disambiguation-source'
    }

    def __init__(self, disambiguated_organization_identifier=None, disambiguation_source=None):  # noqa: E501
        """DisambiguatedOrganizationV30 - a model defined in Swagger"""  # noqa: E501
        self._disambiguated_organization_identifier = None
        self._disambiguation_source = None
        self.discriminator = None
        self.disambiguated_organization_identifier = disambiguated_organization_identifier
        self.disambiguation_source = disambiguation_source

    @property
    def disambiguated_organization_identifier(self):
        """Gets the disambiguated_organization_identifier of this DisambiguatedOrganizationV30.  # noqa: E501


        :return: The disambiguated_organization_identifier of this DisambiguatedOrganizationV30.  # noqa: E501
        :rtype: str
        """
        return self._disambiguated_organization_identifier

    @disambiguated_organization_identifier.setter
    def disambiguated_organization_identifier(self, disambiguated_organization_identifier):
        """Sets the disambiguated_organization_identifier of this DisambiguatedOrganizationV30.


        :param disambiguated_organization_identifier: The disambiguated_organization_identifier of this DisambiguatedOrganizationV30.  # noqa: E501
        :type: str
        """
        if disambiguated_organization_identifier is None:
            raise ValueError("Invalid value for `disambiguated_organization_identifier`, must not be `None`")  # noqa: E501

        self._disambiguated_organization_identifier = disambiguated_organization_identifier

    @property
    def disambiguation_source(self):
        """Gets the disambiguation_source of this DisambiguatedOrganizationV30.  # noqa: E501


        :return: The disambiguation_source of this DisambiguatedOrganizationV30.  # noqa: E501
        :rtype: str
        """
        return self._disambiguation_source

    @disambiguation_source.setter
    def disambiguation_source(self, disambiguation_source):
        """Sets the disambiguation_source of this DisambiguatedOrganizationV30.


        :param disambiguation_source: The disambiguation_source of this DisambiguatedOrganizationV30.  # noqa: E501
        :type: str
        """
        if disambiguation_source is None:
            raise ValueError("Invalid value for `disambiguation_source`, must not be `None`")  # noqa: E501

        self._disambiguation_source = disambiguation_source

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DisambiguatedOrganizationV30, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DisambiguatedOrganizationV30):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
